@@ -11,7 +11,7 @@ if not _RELEASE:
 	)
 else:
 	parent_dir = os.path.dirname(os.path.abspath(__file__))
-	build_dir = os.path.join(parent_dir, "frontend/dist")
+	build_dir = os.path.join(parent_dir, "frontend/build")
 	_component_func = components.declare_component("st_dataframe_component", path=build_dir)
 
 
